@@ -1,4 +1,4 @@
-from .runtime import LoggerRuntimeError
+from .log import LoggerRuntimeError
 
 __all__ = [
     "LoggerRuntimeError",
